==> v1.14.2.tar.gz: lagrange/AUTHORS.md <==
# Authors and Contributors

Lagrange was created by Jaakko Keränen (<jaakko.keranen@iki.fi>) in July 2020. The source code license is **BSD 2-Clause**. UI translations (_*.po_) are under **CC-BY-SA 4.0**.

Legend: `C` code, `T` translation

```
C  3448  Jaakko Keränen <jaakko.keranen@iki.fi>
 T   58  Alyssa Liddell <e-liss@tuta.io>
CT   52  Nikolay Korotkiy <sikmir@gmail.com>
 T   44  Olga Smirnova <mistresssilvara@hotmail.com>
 T   36  Страхиња Радић <contact@strahinja.org>
 T   31  Anna “CyberTailor” <cyber@sysrq.in>
 T   27  Omar Polo <weblate@omarpolo.com>
 T   26  Shibo Lyu <github@of.sb>
 T   25  Wally Hackenslacker <mastor89@protonmail.com>
 T   20  Giosuè Iaccarino <iaccagio9@outlook.it>
 T   19  MCMic <come@chilliet.eu>
 T   19  Xosé M <correoxm@disroot.org>
 T   16  Emir SARI <emir_sari@icloud.com>
 T   14  Tadeáš Erban <tadysekerbosek@gmail.com>
 T    9  Aaron Fischer <mail@aaron-fischer.net>
 T    8  El Mau <public@correolibre.net>
 T    7  Waterrail <maksymiliankrol03@gmail.com>
 T    6  Marco Andronaco <andronacomarco@gmail.com>
 T    5  roy niang <roy@royniang.com>
 T    3  Alex Schroeder <alex@alexschroeder.ch>
 T    3  Botond Balázs <balazsbotond@gmail.com>
C     2  Alyssa Rosenzweig <alyssa@rosenzweig.io>
 T    2  Andrij Mizyk <andmizyk@gmail.com>
 T    2  Arns Udovič <zordsdavini@arns.lt>
C     2  Br0000k <77938600+Br0000k@users.noreply.github.com>
 T    2  Gabriel de Oliveira Ferreira Machado <goliv04053@tutanota.com>
 T    2  Jop Vernooy <jop@jopv.net>
C     2  Manos Pitsidianakis <el13635@mail.ntua.gr>
 T    2  Xavier <dxpublica@posteo.net>
 T    2  dalz <weblate@alsd.eu>
 T    2  methbkts <methbkts@gmail.com>
 T    2  tbodt <tblodt@icloud.com>
C     1  Adam Mizerski <adam@mizerski.pl>
C     1  Charles <charles@cdaniels.net>
C     1  Dario Vladovic <d.vladimyr@gmail.com>
C     1  David Gillies <dave.gillies@gmail.com>
 T    1  Eric <spice2wolf@gmail.com>
 T    1  Florian Viehweger <openbsd@out-of-creativity.de>
 T    1  Marek Ľach <mareklachbc@tutanota.com>
C     1  Raph M <raph@raphm.com>
C     1  SolidHal <hal@halemmerich.com>
C     1  Thomas Adam <thomas.adam@smoothwall.net>
 T    1  Timothée Goguely <timothee@goguely.com>
C     1  Waweic <waweic@activ.ism.rocks>
C     1  Waweic <waweic@protonmail.com>
C     1  Zach DeCook <zachdecook@librem.one>
C     1  jcromero <jcromero+github@disconfor.me>
C     1  jgart <47760695+jgarte@users.noreply.github.com>
C     1  zocker <zocker@10zen.eu>
```

This table of contributors has been extracted from Git history and is sorted by commit count.

==> v1.15.0.tar.gz: lagrange/AUTHORS.md <==
# Authors and Contributors

Lagrange was created by Jaakko Keränen (<jaakko.keranen@iki.fi>) in July 2020. The source code license is **BSD 2-Clause**. UI translations (_*.po_) are under **CC-BY-SA 4.0**.

Legend: `C` code, `T` translation

```
C  3759  Jaakko Keränen <jaakko.keranen@iki.fi>
 T   72  Alyssa Liddell <e-liss@tuta.io>
CT   55  Nikolay Korotkiy <sikmir@gmail.com>
 T   48  Olga Smirnova <mistresssilvara@hotmail.com>
 T   44  Страхиња Радић <contact@strahinja.org>
 T   35  Anna (cybertailor) Vyalkova <cyber@sysrq.in>
 T   31  Wally Hackenslacker <mastor89@protonmail.com>
 T   30  Omar Polo <weblate@omarpolo.com>
 T   27  Emir SARI <emir_sari@icloud.com>
 T   26  Shibo Lyu <github@of.sb>
 T   21  Xosé M <correoxm@disroot.org>
 T   20  Giosuè Iaccarino <iaccagio9@outlook.it>
 T   20  MCMic <come@chilliet.eu>
 T   16  Tadeáš Erban <tadysekerbosek@gmail.com>
 T    9  Aaron Fischer <mail@aaron-fischer.net>
 T    8  El Mau <public@correolibre.net>
 T    8  Waterrail <maksymiliankrol03@gmail.com>
 T    6  Marco Andronaco <andronacomarco@gmail.com>
 T    5  roy niang <roy@royniang.com>
 T    3  Alex Schroeder <alex@alexschroeder.ch>
 T    3  Botond Balázs <balazsbotond@gmail.com>
 T    3  Seiji Delph <george@quotennial.co.uk>
 T    3  tbodt <tblodt@icloud.com>
C     2  Alyssa Rosenzweig <alyssa@rosenzweig.io>
 T    2  Andrij Mizyk <andmizyk@gmail.com>
 T    2  Arns Udovič <zordsdavini@arns.lt>
C     2  Br0000k <77938600+Br0000k@users.noreply.github.com>
 T    2  Gabriel de Oliveira Ferreira Machado <goliv04053@tutanota.com>
 T    2  Jop Vernooy <jop@jopv.net>
C     2  Manos Pitsidianakis <el13635@mail.ntua.gr>
 T    2  Xavier <dxpublica@posteo.net>
 T    2  dalz <weblate@alsd.eu>
 T    2  methbkts <methbkts@gmail.com>
C     1  Adam Mizerski <adam@mizerski.pl>
C     1  Charles <charles@cdaniels.net>
C     1  Dario Vladovic <d.vladimyr@gmail.com>
C     1  David Gillies <dave.gillies@gmail.com>
 T    1  Eric <spice2wolf@gmail.com>
 T    1  Florian Viehweger <openbsd@out-of-creativity.de>
 T    1  Griffen Schwiesow <griffen@zipmail.ch>
 T    1  Marek Ľach <mareklachbc@tutanota.com>
C     1  Raph M <raph@raphm.com>
C     1  Sam Bossley <bossley.samuel@gmail.com>
C     1  SolidHal <hal@halemmerich.com>
C     1  Thomas Adam <thomas.adam@smoothwall.net>
 T    1  Timothée Goguely <timothee@goguely.com>
C     1  Waweic <waweic@activ.ism.rocks>
C     1  Waweic <waweic@protonmail.com>
C     1  Zach DeCook <zachdecook@librem.one>
C     1  jcromero <jcromero+github@disconfor.me>
C     1  jgart <47760695+jgarte@users.noreply.github.com>
C     1  zocker <zocker@10zen.eu>
```

This table of contributors has been extracted from Git history and is sorted by commit count.
